function navigationMenu(screen){
    gotoPage('home', screen, {});
}

function openNav() {
  document.getElementById("mySidenav").style.width = "50%";
}

function closeNav() {
  document.getElementById("mySidenav").style.width = "0";
}

function showLabelPrivate(privated){
    if(!privated){
        document.getElementsByClassName('payments')[0].style.opacity = 0.5;
        document.getElementsByClassName('paymentsResponsive')[0].style.opacity = 0.5;
        
        document.getElementById('paymentLink').style.cursor = "default";
        document.getElementById('paymentLink').setAttribute('href','javascript:void(0)');
        
        document.getElementById('responsiveEstimated').style.cursor = "default";
        document.getElementById('responsiveEstimated').setAttribute('href','javascript:void(0)');
    }
}

function showLabelEstimated(content){
    if(content == 0){
        document.getElementsByClassName('estimatedPupils')[0].style.opacity = 0.5;
        document.getElementsByClassName('estimatedResponsive')[0].style.opacity = 0.5;
        
        document.getElementById('estimatedLink').style.cursor = "default";
        document.getElementById('estimatedLink').setAttribute('href','javascript:void(0)');
        
        document.getElementById('estimatedResponsive').style.cursor = "default";
        document.getElementById('estimatedResponsive').setAttribute('href','javascript:void(0)');
        
        document.getElementsByClassName('payments')[0].style.opacity = 0.5;
        document.getElementsByClassName('paymentsResponsive')[0].style.opacity = 0.5;
        
        document.getElementById('paymentLink').style.cursor = "default";
        document.getElementById('paymentLink').setAttribute('href','javascript:void(0)');
        
        document.getElementById('responsiveEstimated').style.cursor = "default";
        document.getElementById('responsiveEstimated').setAttribute('href','javascript:void(0)');
    }
}

function clearQtyPupils(){
    localStorage.removeItem('qtyPupils');
}
